pub fn check_module_unlocked(
progress: &UserProgress,
engine: &ContentEngine,
era_id: &str,
module_id: &str,
) -> boolExpand description
Check if a specific module is unlocked for the user
pub fn check_module_unlocked(
progress: &UserProgress,
engine: &ContentEngine,
era_id: &str,
module_id: &str,
) -> boolCheck if a specific module is unlocked for the user