pub fn get_module_state(
progress: &UserProgress,
engine: &ContentEngine,
era_id: &str,
module_id: &str,
) -> ModuleStateExpand description
Get the current state of a module for the user
pub fn get_module_state(
progress: &UserProgress,
engine: &ContentEngine,
era_id: &str,
module_id: &str,
) -> ModuleStateGet the current state of a module for the user